=== modified file 'NEWS'
--- NEWS	2010-05-06 23:49:39 +0000
+++ NEWS	2010-05-06 07:48:22 +0000
@@ -13,12 +13,6 @@
 Compatibility Breaks
 ********************
 
-* An API break has been made to the lock_write method of ``Branch`` and
-  ``Repository`` objects; they now return ``branch.BranchWriteLockResult``
-  and ``repository.RepositoryWriteLockResult`` objects. This makes
-  changing the API in future easier and permits some cleaner calling code.
-  (Robert Collins)
-
 New Features
 ************
 
@@ -102,19 +96,9 @@
   implementations.
   (Martin Pool)
 
-* Lock methods on ``Tree``, ``Branch`` and ``Repository`` are now
-  expected to return an object which can be used to unlock them. This reduces
-  duplicate code when using cleanups. The previous 'tokens's returned by
-  ``Branch.lock_write`` and ``Repository.lock_write`` are now attributes
-  on the result of the lock_write. ``repository.RepositoryWriteLockResult``
-  and ``branch.BranchWriteLockResult`` document this. (Robert Collins)
-
 Internals
 *********
 
-* ``log._get_info_for_log_files`` now takes an add_cleanup callable.
-  (Robert Collins)
-
 * ``_remember_remote_is_before`` no longer raises AssertionError when
   suboptimal network behaviour is noticed; instead it just mutters to the
   log file (and warns the user if they have set the ``hpss`` debug flag).

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2010-05-06 23:54:05 +0000
+++ bzrlib/branch.py	2010-04-28 09:40:23 +0000
@@ -283,21 +283,10 @@
         new_history.reverse()
         return new_history
 
-    def lock_write(self, token=None):
-        """Lock the branch for write operations.
-
-        :param token: A token to permit reacquiring a previously held and
-            preserved lock.
-        :return: A BranchWriteLockResult.
-        """
+    def lock_write(self):
         raise NotImplementedError(self.lock_write)
 
     def lock_read(self):
-        """Lock the branch for read operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
         raise NotImplementedError(self.lock_read)
 
     def unlock(self):
@@ -2276,23 +2265,6 @@
     _legacy_formats[0].network_name(), _legacy_formats[0].__class__)
 
 
-class BranchWriteLockResult(object):
-    """The result of write locking a branch.
-
-    :ivar branch_token: The token obtained from the underlying branch lock, or
-        None.
-    :ivar unlock: A callable which will unlock the lock.
-    """
-
-    def __init__(self, unlock, branch_token):
-        self.branch_token = branch_token
-        self.unlock = unlock
-
-    def __str__(self):
-        return "BranchWriteLockResult(%s, %s)" % (self.branch_token,
-            self.unlock)
-
-
 class BzrBranch(Branch, _RelockDebugMixin):
     """A branch stored in the actual filesystem.
 
@@ -2352,12 +2324,6 @@
         return self.control_files.is_locked()
 
     def lock_write(self, token=None):
-        """Lock the branch for write operations.
-
-        :param token: A token to permit reacquiring a previously held and
-            preserved lock.
-        :return: A BranchWriteLockResult.
-        """
         if not self.is_locked():
             self._note_lock('w')
         # All-in-one needs to always unlock/lock.
@@ -2369,19 +2335,13 @@
         else:
             took_lock = False
         try:
-            return BranchWriteLockResult(self.unlock,
-                self.control_files.lock_write(token=token))
+            return self.control_files.lock_write(token=token)
         except:
             if took_lock:
                 self.repository.unlock()
             raise
 
     def lock_read(self):
-        """Lock the branch for read operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
         if not self.is_locked():
             self._note_lock('r')
         # All-in-one needs to always unlock/lock.
@@ -2394,7 +2354,6 @@
             took_lock = False
         try:
             self.control_files.lock_read()
-            return self
         except:
             if took_lock:
                 self.repository.unlock()

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-05-06 23:41:35 +0000
+++ bzrlib/builtins.py	2010-05-03 09:07:50 +0000
@@ -528,9 +528,10 @@
         if tree:
             try:
                 wt = WorkingTree.open_containing(location)[0]
-                self.add_cleanup(wt.lock_read().unlock)
+                wt.lock_read()
             except (errors.NoWorkingTree, errors.NotLocalUrl):
                 raise errors.NoWorkingTree(location)
+            self.add_cleanup(wt.unlock)
             revid = wt.last_revision()
             try:
                 revno_t = wt.branch.revision_id_to_dotted_revno(revid)
@@ -539,7 +540,8 @@
             revno = ".".join(str(n) for n in revno_t)
         else:
             b = Branch.open_containing(location)[0]
-            self.add_cleanup(b.lock_read().unlock)
+            b.lock_read()
+            self.add_cleanup(b.unlock)
             revno = b.revno()
         self.cleanup_now()
         self.outf.write(str(revno) + '\n')
@@ -568,11 +570,13 @@
         try:
             wt = WorkingTree.open_containing(directory)[0]
             b = wt.branch
-            self.add_cleanup(wt.lock_read().unlock)
+            wt.lock_read()
+            self.add_cleanup(wt.unlock)
         except (errors.NoWorkingTree, errors.NotLocalUrl):
             wt = None
             b = Branch.open_containing(directory)[0]
-            self.add_cleanup(b.lock_read().unlock)
+            b.lock_read()
+            self.add_cleanup(b.unlock)
         revision_ids = []
         if revision is not None:
             revision_ids.extend(rev.as_revision_id(b) for rev in revision)
@@ -677,7 +681,8 @@
                 should_print=(not is_quiet()))
 
         if base_tree:
-            self.add_cleanup(base_tree.lock_read().unlock)
+            base_tree.lock_read()
+            self.add_cleanup(base_tree.unlock)
         tree, file_list = tree_files_for_add(file_list)
         added, ignored = tree.smart_add(file_list, not
             no_recurse, action=action, save=not dry_run)
@@ -755,12 +760,14 @@
 
         revision = _get_one_revision('inventory', revision)
         work_tree, file_list = tree_files(file_list)
-        self.add_cleanup(work_tree.lock_read().unlock)
+        work_tree.lock_read()
+        self.add_cleanup(work_tree.unlock)
         if revision is not None:
             tree = revision.as_tree(work_tree.branch)
 
             extra_trees = [work_tree]
-            self.add_cleanup(tree.lock_read().unlock)
+            tree.lock_read()
+            self.add_cleanup(tree.unlock)
         else:
             tree = work_tree
             extra_trees = []
@@ -826,7 +833,8 @@
         if len(names_list) < 2:
             raise errors.BzrCommandError("missing file argument")
         tree, rel_names = tree_files(names_list, canonicalize=False)
-        self.add_cleanup(tree.lock_tree_write().unlock)
+        tree.lock_tree_write()
+        self.add_cleanup(tree.unlock)
         self._run(tree, names_list, rel_names, after)
 
     def run_auto(self, names_list, after, dry_run):
@@ -837,7 +845,8 @@
             raise errors.BzrCommandError('--after cannot be specified with'
                                          ' --auto.')
         work_tree, file_list = tree_files(names_list, default_branch='.')
-        self.add_cleanup(work_tree.lock_tree_write().unlock)
+        work_tree.lock_tree_write()
+        self.add_cleanup(work_tree.unlock)
         rename_map.RenameMap.guess_renames(work_tree, dry_run)
 
     def _run(self, tree, names_list, rel_names, after):
@@ -977,11 +986,13 @@
         try:
             tree_to = WorkingTree.open_containing(directory)[0]
             branch_to = tree_to.branch
-            self.add_cleanup(tree_to.lock_write().unlock)
+            tree_to.lock_write()
+            self.add_cleanup(tree_to.unlock)
         except errors.NoWorkingTree:
             tree_to = None
             branch_to = Branch.open_containing(directory)[0]
-            self.add_cleanup(branch_to.lock_write().unlock)
+            branch_to.lock_write()
+            self.add_cleanup(branch_to.unlock)
 
         if local and not branch_to.get_bound_location():
             raise errors.LocalRequiresBoundBranch()
@@ -1018,7 +1029,8 @@
         else:
             branch_from = Branch.open(location,
                 possible_transports=possible_transports)
-            self.add_cleanup(branch_from.lock_read().unlock)
+            branch_from.lock_read()
+            self.add_cleanup(branch_from.unlock)
 
             if branch_to.get_parent() is None or remember:
                 branch_to.set_parent(branch_from.base)
@@ -1207,7 +1219,8 @@
         accelerator_tree, br_from = bzrdir.BzrDir.open_tree_or_branch(
             from_location)
         revision = _get_one_revision('branch', revision)
-        self.add_cleanup(br_from.lock_read().unlock)
+        br_from.lock_read()
+        self.add_cleanup(br_from.unlock)
         if revision is not None:
             revision_id = revision.as_revision_id(br_from)
         else:
@@ -1353,10 +1366,12 @@
     @display_command
     def run(self, dir=u'.'):
         tree = WorkingTree.open_containing(dir)[0]
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         new_inv = tree.inventory
         old_tree = tree.basis_tree()
-        self.add_cleanup(old_tree.lock_read().unlock)
+        old_tree.lock_read()
+        self.add_cleanup(old_tree.unlock)
         old_inv = old_tree.inventory
         renames = []
         iterator = tree.iter_changes(old_tree, include_unchanged=True)
@@ -1400,11 +1415,11 @@
         master = branch.get_master_branch(
             possible_transports=possible_transports)
         if master is not None:
+            tree.lock_write()
             branch_location = master.base
-            tree.lock_write()
         else:
+            tree.lock_tree_write()
             branch_location = tree.branch.base
-            tree.lock_tree_write()
         self.add_cleanup(tree.unlock)
         # get rid of the final '/' and be ready for display
         branch_location = urlutils.unescape_for_display(
@@ -1530,7 +1545,8 @@
         if file_list is not None:
             file_list = [f for f in file_list]
 
-        self.add_cleanup(tree.lock_write().unlock)
+        tree.lock_write()
+        self.add_cleanup(tree.unlock)
         # Heuristics should probably all move into tree.remove_smart or
         # some such?
         if new:
@@ -1992,9 +2008,11 @@
     @display_command
     def run(self, show_ids=False):
         tree = WorkingTree.open_containing(u'.')[0]
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         old = tree.basis_tree()
-        self.add_cleanup(old.lock_read().unlock)
+        old.lock_read()
+        self.add_cleanup(old.unlock)
         for path, ie in old.inventory.iter_entries():
             if not tree.has_id(ie.file_id):
                 self.outf.write(path)
@@ -2042,9 +2060,11 @@
     @display_command
     def run(self, null=False):
         wt = WorkingTree.open_containing(u'.')[0]
-        self.add_cleanup(wt.lock_read().unlock)
+        wt.lock_read()
+        self.add_cleanup(wt.unlock)
         basis = wt.basis_tree()
-        self.add_cleanup(basis.lock_read().unlock)
+        basis.lock_read()
+        self.add_cleanup(basis.unlock)
         basis_inv = basis.inventory
         inv = wt.inventory
         for file_id in inv:
@@ -2332,7 +2352,8 @@
         if file_list:
             # find the file ids to log and check for directory filtering
             b, file_info_list, rev1, rev2 = _get_info_for_log_files(
-                revision, file_list, self.add_cleanup)
+                revision, file_list)
+            self.add_cleanup(b.unlock)
             for relpath, file_id, kind in file_info_list:
                 if file_id is None:
                     raise errors.BzrCommandError(
@@ -2356,7 +2377,8 @@
                 location = '.'
             dir, relpath = bzrdir.BzrDir.open_containing(location)
             b = dir.open_branch()
-            self.add_cleanup(b.lock_read().unlock)
+            b.lock_read()
+            self.add_cleanup(b.unlock)
             rev1, rev2 = _get_revision_range(revision, b, self.name())
 
         # Decide on the type of delta & diff filtering to use
@@ -2486,7 +2508,8 @@
         tree, relpath = WorkingTree.open_containing(filename)
         file_id = tree.path2id(relpath)
         b = tree.branch
-        self.add_cleanup(b.lock_read().unlock)
+        b.lock_read()
+        self.add_cleanup(b.unlock)
         touching_revs = log.find_touching_revisions(b, file_id)
         for revno, revision_id, what in touching_revs:
             self.outf.write("%6d %s\n" % (revno, what))
@@ -2561,7 +2584,8 @@
                 view_str = views.view_display_str(view_files)
                 note("Ignoring files outside view. View is %s" % view_str)
 
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         for fp, fc, fkind, fid, entry in tree.list_files(include_root=False,
             from_dir=relpath, recursive=recursive):
             # Apply additional masking
@@ -2746,7 +2770,8 @@
     @display_command
     def run(self):
         tree = WorkingTree.open_containing(u'.')[0]
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         for path, file_class, kind, file_id, entry in tree.list_files():
             if file_class != 'I':
                 continue
@@ -2865,7 +2890,8 @@
                                          " one revision specifier")
         tree, branch, relpath = \
             bzrdir.BzrDir.open_containing_tree_or_branch(filename)
-        self.add_cleanup(branch.lock_read().unlock)
+        branch.lock_read()
+        self.add_cleanup(branch.unlock)
         return self._run(tree, branch, relpath, filename, revision,
                          name_from_revision, filters)
 
@@ -2874,7 +2900,8 @@
         if tree is None:
             tree = b.basis_tree()
         rev_tree = _get_one_revision_tree('cat', revision, branch=b)
-        self.add_cleanup(rev_tree.lock_read().unlock)
+        rev_tree.lock_read()
+        self.add_cleanup(rev_tree.unlock)
 
         old_file_id = rev_tree.path2id(relpath)
 
@@ -3663,8 +3690,10 @@
 
         branch1 = Branch.open_containing(branch)[0]
         branch2 = Branch.open_containing(other)[0]
-        self.add_cleanup(branch1.lock_read().unlock)
-        self.add_cleanup(branch2.lock_read().unlock)
+        branch1.lock_read()
+        self.add_cleanup(branch1.unlock)
+        branch2.lock_read()
+        self.add_cleanup(branch2.unlock)
         last1 = ensure_null(branch1.last_revision())
         last2 = ensure_null(branch2.last_revision())
 
@@ -3808,7 +3837,8 @@
             unversioned_filter=tree.is_ignored, view_info=view_info)
         pb = ui.ui_factory.nested_progress_bar()
         self.add_cleanup(pb.finished)
-        self.add_cleanup(tree.lock_write().unlock)
+        tree.lock_write()
+        self.add_cleanup(tree.unlock)
         if location is not None:
             try:
                 mergeable = bundle.read_mergeable_from_url(location,
@@ -4070,7 +4100,8 @@
         if merge_type is None:
             merge_type = _mod_merge.Merge3Merger
         tree, file_list = tree_files(file_list)
-        self.add_cleanup(tree.lock_write().unlock)
+        tree.lock_write()
+        self.add_cleanup(tree.unlock)
         parents = tree.get_parent_ids()
         if len(parents) != 2:
             raise errors.BzrCommandError("Sorry, remerge only works after normal"
@@ -4186,7 +4217,8 @@
     def run(self, revision=None, no_backup=False, file_list=None,
             forget_merges=None):
         tree, file_list = tree_files(file_list)
-        self.add_cleanup(tree.lock_tree_write().unlock)
+        tree.lock_tree_write()
+        self.add_cleanup(tree.unlock)
         if forget_merges:
             tree.set_parent_ids(tree.get_parent_ids()[:1])
         else:
@@ -4328,7 +4360,8 @@
             restrict = 'remote'
 
         local_branch = Branch.open_containing(u".")[0]
-        self.add_cleanup(local_branch.lock_read().unlock)
+        local_branch.lock_read()
+        self.add_cleanup(local_branch.unlock)
 
         parent = local_branch.get_parent()
         if other_branch is None:
@@ -4345,7 +4378,8 @@
         if remote_branch.base == local_branch.base:
             remote_branch = local_branch
         else:
-            self.add_cleanup(remote_branch.lock_read().unlock)
+            remote_branch.lock_read()
+            self.add_cleanup(remote_branch.unlock)
 
         local_revid_range = _revision_range_to_revid_range(
             _get_revision_range(my_revision, local_branch,
@@ -4406,7 +4440,8 @@
             message("Branches are up to date.\n")
         self.cleanup_now()
         if not status_code and parent is None and other_branch is not None:
-            self.add_cleanup(local_branch.lock_write().unlock)
+            local_branch.lock_write()
+            self.add_cleanup(local_branch.unlock)
             # handle race conditions - a parent might be set while we run.
             if local_branch.get_parent() is None:
                 local_branch.set_parent(remote_branch.base)
@@ -4512,7 +4547,8 @@
             b = Branch.open_containing(branch)[0]
         else:
             b = Branch.open(branch)
-        self.add_cleanup(b.lock_read().unlock)
+        b.lock_read()
+        self.add_cleanup(b.unlock)
         if revision is None:
             rev_id = b.last_revision()
         else:
@@ -4552,11 +4588,14 @@
         wt, branch, relpath = \
             bzrdir.BzrDir.open_containing_tree_or_branch(filename)
         if wt is not None:
-            self.add_cleanup(wt.lock_read().unlock)
+            wt.lock_read()
+            self.add_cleanup(wt.unlock)
         else:
-            self.add_cleanup(branch.lock_read().unlock)
+            branch.lock_read()
+            self.add_cleanup(branch.unlock)
         tree = _get_one_revision_tree('annotate', revision, branch=branch)
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         if wt is not None:
             file_id = wt.path2id(relpath)
         else:
@@ -4588,7 +4627,8 @@
         if revision_id_list is None and revision is None:
             raise errors.BzrCommandError('You must supply either --revision or a revision_id')
         b = WorkingTree.open_containing(u'.')[0].branch
-        self.add_cleanup(b.lock_write().unlock)
+        b.lock_write()
+        self.add_cleanup(b.unlock)
         return self._run(b, revision_id_list, revision)
 
     def _run(self, b, revision_id_list, revision):
@@ -4744,9 +4784,11 @@
             b = control.open_branch()
 
         if tree is not None:
-            self.add_cleanup(tree.lock_write().unlock)
+            tree.lock_write()
+            self.add_cleanup(tree.unlock)
         else:
-            self.add_cleanup(b.lock_write().unlock)
+            b.lock_write()
+            self.add_cleanup(b.unlock)
         return self._run(b, tree, dry_run, verbose, revision, force, local=local)
 
     def _run(self, b, tree, dry_run, verbose, revision, force, local=False):
@@ -5315,7 +5357,8 @@
             revision=None,
             ):
         branch, relpath = Branch.open_containing(directory)
-        self.add_cleanup(branch.lock_write().unlock)
+        branch.lock_write()
+        self.add_cleanup(branch.unlock)
         if delete:
             if tag_name is None:
                 raise errors.BzrCommandError("No tag specified to delete.")
@@ -5376,7 +5419,8 @@
         if not tags:
             return
 
-        self.add_cleanup(branch.lock_read().unlock)
+        branch.lock_read()
+        self.add_cleanup(branch.unlock)
         if revision:
             graph = branch.repository.get_graph()
             rev1, rev2 = _get_revision_range(revision, branch, self.name())
@@ -5860,7 +5904,8 @@
 
     def run_for_list(self):
         tree = WorkingTree.open_containing('.')[0]
-        self.add_cleanup(tree.lock_read().unlock)
+        tree.lock_read()
+        self.add_cleanup(tree.unlock)
         manager = tree.get_shelf_manager()
         shelves = manager.active_shelves()
         if len(shelves) == 0:

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2010-05-06 23:41:35 +0000
+++ bzrlib/log.py	2010-04-14 12:30:17 +0000
@@ -1930,7 +1930,7 @@
         lf.log_revision(lr)
 
 
-def _get_info_for_log_files(revisionspec_list, file_list, add_cleanup):
+def _get_info_for_log_files(revisionspec_list, file_list):
     """Find file-ids and kinds given a list of files and a revision range.
 
     We search for files at the end of the range. If not found there,
@@ -1940,8 +1940,6 @@
     :param file_list: the list of paths given on the command line;
       the first of these can be a branch location or a file path,
       the remainder must be file paths
-    :param add_cleanup: When the branch returned is read locked,
-      an unlock call will be queued to the cleanup.
     :return: (branch, info_list, start_rev_info, end_rev_info) where
       info_list is a list of (relative_path, file_id, kind) tuples where
       kind is one of values 'directory', 'file', 'symlink', 'tree-reference'.
@@ -1949,7 +1947,7 @@
     """
     from builtins import _get_revision_range, safe_relpath_files
     tree, b, path = bzrdir.BzrDir.open_containing_tree_or_branch(file_list[0])
-    add_cleanup(b.lock_read().unlock)
+    b.lock_read()
     # XXX: It's damn messy converting a list of paths to relative paths when
     # those paths might be deleted ones, they might be on a case-insensitive
     # filesystem and/or they might be in silly locations (like another branch).

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2010-05-06 23:41:35 +0000
+++ bzrlib/remote.py	2010-05-03 04:08:50 +0000
@@ -33,7 +33,7 @@
     static_tuple,
     symbol_versioning,
 )
-from bzrlib.branch import BranchReferenceFormat, BranchWriteLockResult
+from bzrlib.branch import BranchReferenceFormat
 from bzrlib.bzrdir import BzrDir, RemoteBzrDirFormat
 from bzrlib.decorators import needs_read_lock, needs_write_lock, only_raises
 from bzrlib.errors import (
@@ -43,7 +43,6 @@
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.smart import client, vfs, repository as smart_repo
 from bzrlib.revision import ensure_null, NULL_REVISION
-from bzrlib.repository import RepositoryWriteLockResult
 from bzrlib.trace import mutter, note, warning
 
 
@@ -998,11 +997,6 @@
         pass
 
     def lock_read(self):
-        """Lock the repository for read operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
         # wrong eventually - want a local lock cache context
         if not self._lock_mode:
             self._note_lock('r')
@@ -1015,7 +1009,6 @@
                 repo.lock_read()
         else:
             self._lock_count += 1
-        return self
 
     def _remote_lock_write(self, token):
         path = self.bzrdir._path_for_remote_call(self._client)
@@ -1061,7 +1054,7 @@
             raise errors.ReadOnlyError(self)
         else:
             self._lock_count += 1
-        return RepositoryWriteLockResult(self.unlock, self._lock_token or None)
+        return self._lock_token or None
 
     def leave_lock_in_place(self):
         if not self._lock_token:
@@ -2394,11 +2387,6 @@
             self._vfs_set_tags_bytes(bytes)
 
     def lock_read(self):
-        """Lock the branch for read operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
         self.repository.lock_read()
         if not self._lock_mode:
             self._note_lock('r')
@@ -2408,14 +2396,13 @@
                 self._real_branch.lock_read()
         else:
             self._lock_count += 1
-        return self
 
     def _remote_lock_write(self, token):
         if token is None:
             branch_token = repo_token = ''
         else:
             branch_token = token
-            repo_token = self.repository.lock_write().repository_token
+            repo_token = self.repository.lock_write()
             self.repository.unlock()
         err_context = {'token': token}
         response = self._call(
@@ -2458,7 +2445,7 @@
             self._lock_count += 1
             # Re-lock the repository too.
             self.repository.lock_write(self._repo_lock_token)
-        return BranchWriteLockResult(self.unlock, self._lock_token or None)
+        return self._lock_token or None
 
     def _unlock(self, branch_token, repo_token):
         err_context = {'token': str((branch_token, repo_token))}

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2010-05-06 23:41:35 +0000
+++ bzrlib/repofmt/pack_repo.py	2010-04-22 17:08:27 +0000
@@ -69,7 +69,6 @@
     CommitBuilder,
     MetaDirRepositoryFormat,
     RepositoryFormat,
-    RepositoryWriteLockResult,
     RootCommitBuilder,
     StreamSource,
     )
@@ -2355,7 +2354,6 @@
                 # Writes don't affect fallback repos
                 repo.lock_read()
             self._refresh_data()
-        return RepositoryWriteLockResult(self.unlock, None)
 
     def lock_read(self):
         locked = self.is_locked()
@@ -2370,7 +2368,6 @@
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
-        return self
 
     def leave_lock_in_place(self):
         # not supported - raise an error

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2010-05-06 23:54:05 +0000
+++ bzrlib/repository.py	2010-04-28 07:03:38 +0000
@@ -860,23 +860,6 @@
         # versioned roots do not change unless the tree found a change.
 
 
-class RepositoryWriteLockResult(object):
-    """The result of write locking a repository.
-
-    :ivar repository_token: The token obtained from the underlying lock, or
-        None.
-    :ivar unlock: A callable which will unlock the lock.
-    """
-
-    def __init__(self, unlock, repository_token):
-        self.repository_token = repository_token
-        self.unlock = unlock
-
-    def __str__(self):
-        return "RepositoryWriteLockResult(%s, %s)" % (self.repository_token,
-            self.unlock)
-
-
 ######################################################################
 # Repositories
 
@@ -1393,12 +1376,6 @@
         data during reads, and allows a 'write_group' to be obtained. Write
         groups must be used for actual data insertion.
 
-        A token should be passed in if you know that you have locked the object
-        some other way, and need to synchronise this object's state with that
-        fact.
-
-        XXX: this docstring is duplicated in many places, e.g. lockable_files.py
-
         :param token: if this is already locked, then lock_write will fail
             unless the token matches the existing lock.
         :returns: a token if this instance supports tokens, otherwise None.
@@ -1407,10 +1384,15 @@
         :raises MismatchedToken: if the specified token doesn't match the token
             of the existing lock.
         :seealso: start_write_group.
-        :return: A RepositoryWriteLockResult.
+
+        A token should be passed in if you know that you have locked the object
+        some other way, and need to synchronise this object's state with that
+        fact.
+
+        XXX: this docstring is duplicated in many places, e.g. lockable_files.py
         """
         locked = self.is_locked()
-        token = self.control_files.lock_write(token=token)
+        result = self.control_files.lock_write(token=token)
         if not locked:
             self._warn_if_deprecated()
             self._note_lock('w')
@@ -1418,14 +1400,9 @@
                 # Writes don't affect fallback repos
                 repo.lock_read()
             self._refresh_data()
-        return RepositoryWriteLockResult(self.unlock, token)
+        return result
 
     def lock_read(self):
-        """Lock the repository for read operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
         locked = self.is_locked()
         self.control_files.lock_read()
         if not locked:
@@ -1434,7 +1411,6 @@
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
-        return self
 
     def get_physical_lock_status(self):
         return self.control_files.get_physical_lock_status()

=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2010-05-06 23:41:35 +0000
+++ bzrlib/revisiontree.py	2010-04-30 11:03:59 +0000
@@ -174,12 +174,8 @@
         return set(self._repository.get_ancestry(self._revision_id,
                                                  topo_sorted=False))
 
-    def is_locked(self):
-        return self._repository.is_locked()
-
     def lock_read(self):
         self._repository.lock_read()
-        return self
 
     def __repr__(self):
         return '<%s instance at %x, rev_id=%r>' % (

=== modified file 'bzrlib/smart/branch.py'
--- bzrlib/smart/branch.py	2010-05-06 23:41:35 +0000
+++ bzrlib/smart/branch.py	2009-10-21 06:05:49 +0000
@@ -292,11 +292,9 @@
         if repo_token == '':
             repo_token = None
         try:
-            repo_token = branch.repository.lock_write(
-                token=repo_token).repository_token
+            repo_token = branch.repository.lock_write(token=repo_token)
             try:
-                branch_token = branch.lock_write(
-                    token=branch_token).branch_token
+                branch_token = branch.lock_write(token=branch_token)
             finally:
                 # this leaves the repository with 1 lock
                 branch.repository.unlock()

=== modified file 'bzrlib/smart/bzrdir.py'
--- bzrlib/smart/bzrdir.py	2010-05-06 23:41:35 +0000
+++ bzrlib/smart/bzrdir.py	2010-04-23 00:44:15 +0000
@@ -429,7 +429,7 @@
             # It is returned locked, but we need to do the lock to get the lock
             # token.
             repo.unlock()
-            repo_lock_token = repo.lock_write().repository_token or ''
+            repo_lock_token = repo.lock_write() or ''
             if repo_lock_token:
                 repo.leave_lock_in_place()
             repo.unlock()

=== modified file 'bzrlib/smart/repository.py'
--- bzrlib/smart/repository.py	2010-05-06 23:41:35 +0000
+++ bzrlib/smart/repository.py	2010-03-25 07:34:15 +0000
@@ -392,7 +392,7 @@
         if token == '':
             token = None
         try:
-            token = repository.lock_write(token=token).repository_token
+            token = repository.lock_write(token=token)
         except errors.LockContention, e:
             return FailedSmartServerResponse(('LockContention',))
         except errors.UnlockableTransport:

=== modified file 'bzrlib/tests/per_branch/test_break_lock.py'
--- bzrlib/tests/per_branch/test_break_lock.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_branch/test_break_lock.py	2010-02-10 17:52:08 +0000
@@ -41,7 +41,7 @@
     def test_unlocked_repo_locked(self):
         # break lock on the branch should try on the repository even
         # if the branch isn't locked
-        token = self.branch.repository.lock_write().repository_token
+        token = self.branch.repository.lock_write()
         if token is None:
             self.branch.repository.unlock()
             raise tests.TestNotApplicable(

=== modified file 'bzrlib/tests/per_branch/test_locking.py'
--- bzrlib/tests/per_branch/test_locking.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_branch/test_locking.py	2010-02-10 17:52:08 +0000
@@ -25,7 +25,6 @@
     lock_helpers,
     per_branch,
     )
-from bzrlib.tests.matchers import *
 
 
 class TestBranchLocking(per_branch.TestCaseWithBranch):
@@ -292,7 +291,7 @@
 
     def test_lock_write_returns_None_refuses_token(self):
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is not None:
                 # This test does not apply, because this lockable supports
@@ -305,7 +304,7 @@
 
     def test_reentering_lock_write_raises_on_token_mismatch(self):
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this lockable refuses
@@ -322,7 +321,7 @@
 
     def test_lock_write_with_nonmatching_token(self):
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this branch refuses
@@ -345,7 +344,7 @@
         """Test that a branch can be locked with a token, if it is already
         locked by that token."""
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this branch refuses tokens.
@@ -369,7 +368,7 @@
         # If lock_write did not physically acquire the lock (because it was
         # passed some tokens), then unlock should not physically release it.
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this lockable refuses
@@ -391,17 +390,19 @@
         # to lock with a token that is no longer valid (because the original
         # lock was released).
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         branch.unlock()
         if token is None:
             # This test does not apply, because this lockable refuses
             # tokens.
             return
-        self.assertRaises(errors.TokenMismatch, branch.lock_write, token=token)
+
+        self.assertRaises(errors.TokenMismatch,
+                          branch.lock_write, token=token)
 
     def test_lock_write_reenter_with_token(self):
         branch = self.make_branch('b')
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this lockable refuses
@@ -419,15 +420,11 @@
         new_branch.lock_write()
         new_branch.unlock()
 
-    def test_lock_write_returns_unlockable(self):
-        branch = self.make_branch('b')
-        self.assertThat(branch.lock_write, ReturnsUnlockable(branch))
-
     def test_leave_lock_in_place(self):
         branch = self.make_branch('b')
         # Lock the branch, then use leave_lock_in_place so that when we
         # unlock the branch the lock is still held on disk.
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this repository refuses lock
@@ -448,7 +445,7 @@
     def test_dont_leave_lock_in_place(self):
         branch = self.make_branch('b')
         # Create a lock on disk.
-        token = branch.lock_write().branch_token
+        token = branch.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this branch refuses lock
@@ -500,10 +497,6 @@
         branch.lock_read()
         branch.unlock()
 
-    def test_lock_read_returns_unlockable(self):
-        branch = self.make_branch('b')
-        self.assertThat(branch.lock_read, ReturnsUnlockable(branch))
-
     def test_lock_write_locks_repo_too(self):
         if isinstance(self.branch_format, _mod_branch.BzrBranchFormat4):
             # Branch format 4 is combined with the repository, so this test
@@ -530,10 +523,6 @@
         finally:
             branch.unlock()
 
-    def test_lock_write_returns_unlockable(self):
-        branch = self.make_branch('b')
-        self.assertThat(branch.lock_write, ReturnsUnlockable(branch))
-
     def test_lock_and_unlock_leaves_repo_unlocked(self):
         branch = self.make_branch('b')
         branch.lock_write()

=== modified file 'bzrlib/tests/per_pack_repository.py'
--- bzrlib/tests/per_pack_repository.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_pack_repository.py	2010-03-18 05:24:02 +0000
@@ -720,16 +720,6 @@
         self.assertEqual(self.format_supports_external_lookups,
             repo._format.supports_external_lookups)
 
-    def _lock_write(self, write_lockable):
-        """Lock write_lockable, add a cleanup and return the result.
-        
-        :param write_lockable: An object with a lock_write method.
-        :return: The result of write_lockable.lock_write().
-        """
-        result = write_lockable.lock_write()
-        self.addCleanup(result.unlock)
-        return result
-
     def test_abort_write_group_does_not_raise_when_suppressed(self):
         """Similar to per_repository.test_write_group's test of the same name.
 
@@ -737,7 +727,8 @@
         """
         self.vfs_transport_factory = memory.MemoryServer
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         # Damage the repository on the filesystem
         self.get_transport('').rename('repo', 'foo')
@@ -753,7 +744,8 @@
     def test_abort_write_group_does_raise_when_not_suppressed(self):
         self.vfs_transport_factory = memory.MemoryServer
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         # Damage the repository on the filesystem
         self.get_transport('').rename('repo', 'foo')
@@ -765,7 +757,8 @@
     def test_suspend_write_group(self):
         self.vfs_transport_factory = memory.MemoryServer
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         repo.texts.add_lines(('file-id', 'revid'), (), ['lines'])
         wg_tokens = repo.suspend_write_group()
@@ -786,7 +779,8 @@
         repo = self.make_repository('repo', format=self.get_format())
         if repo.chk_bytes is None:
             raise TestNotApplicable('no chk_bytes for this repository')
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         text = 'a bit of text\n'
         key = ('sha1:' + osutils.sha_string(text),)
@@ -807,7 +801,8 @@
         # Create a repo, start a write group, insert some data, suspend.
         self.vfs_transport_factory = memory.MemoryServer
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         text_key = ('file-id', 'revid')
         repo.texts.add_lines(text_key, (), ['lines'])
@@ -827,7 +822,8 @@
     def test_commit_resumed_write_group(self):
         self.vfs_transport_factory = memory.MemoryServer
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         text_key = ('file-id', 'revid')
         repo.texts.add_lines(text_key, (), ['lines'])
@@ -855,14 +851,16 @@
         self.vfs_transport_factory = memory.MemoryServer
         # Make a repository with a suspended write group
         repo = self.make_repository('repo', format=self.get_format())
-        token = self._lock_write(repo).repository_token
+        token = repo.lock_write()
+        self.addCleanup(repo.unlock)
         repo.start_write_group()
         text_key = ('file-id', 'revid')
         repo.texts.add_lines(text_key, (), ['lines'])
         wg_tokens = repo.suspend_write_group()
         # Make a new repository
         new_repo = self.make_repository('new_repo', format=self.get_format())
-        token = self._lock_write(new_repo).repository_token
+        token = new_repo.lock_write()
+        self.addCleanup(new_repo.unlock)
         hacked_wg_token = (
             '../../../../repo/.bzr/repository/upload/' + wg_tokens[0])
         self.assertRaises(

=== modified file 'bzrlib/tests/per_repository/test_refresh_data.py'
--- bzrlib/tests/per_repository/test_refresh_data.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_repository/test_refresh_data.py	2009-03-23 14:59:43 +0000
@@ -58,7 +58,7 @@
         source = self.make_branch_and_tree('source')
         revid = source.commit('foo')
         repo = self.make_repository('target')
-        token = repo.lock_write().repository_token
+        token = repo.lock_write()
         self.addCleanup(repo.unlock)
         # Force data reading on weaves/knits
         repo.revisions.keys()

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2010-04-21 04:53:33 +0000
@@ -47,7 +47,6 @@
     per_repository,
     test_server,
     )
-from bzrlib.tests.matchers import *
 
 
 class TestRepositoryMakeBranchAndTree(per_repository.TestCaseWithRepository):
@@ -1088,7 +1087,7 @@
         repo = self.make_repository('r')
         # Lock the repository, then use leave_lock_in_place so that when we
         # unlock the repository the lock is still held on disk.
-        token = repo.lock_write().repository_token
+        token = repo.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this repository refuses lock
@@ -1108,7 +1107,7 @@
     def test_dont_leave_lock_in_place(self):
         repo = self.make_repository('r')
         # Create a lock on disk.
-        token = repo.lock_write().repository_token
+        token = repo.lock_write()
         try:
             if token is None:
                 # This test does not apply, because this repository refuses lock
@@ -1142,14 +1141,6 @@
         repo.lock_read()
         repo.unlock()
 
-    def test_lock_read_returns_unlockable(self):
-        repo = self.make_repository('r')
-        self.assertThat(repo.lock_read, ReturnsUnlockable(repo))
-
-    def test_lock_write_returns_unlockable(self):
-        repo = self.make_repository('r')
-        self.assertThat(repo.lock_write, ReturnsUnlockable(repo))
-
 
 class TestCaseWithComplexRepository(per_repository.TestCaseWithRepository):
 

=== modified file 'bzrlib/tests/per_tree/__init__.py'
--- bzrlib/tests/per_tree/__init__.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_tree/__init__.py	2010-02-10 17:52:08 +0000
@@ -386,7 +386,6 @@
         'inv',
         'iter_search_rules',
         'list_files',
-        'locking',
         'path_content_summary',
         'revision_tree',
         'test_trees',

=== removed file 'bzrlib/tests/per_tree/test_locking.py'
--- bzrlib/tests/per_tree/test_locking.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_tree/test_locking.py	1970-01-01 00:00:00 +0000
@@ -1,28 +0,0 @@
-# Copyright (C) 2010 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""Test that all trees support Tree.lock_read()"""
-
-from bzrlib.tests.matchers import *
-from bzrlib.tests.per_tree import TestCaseWithTree
-
-
-class TestLocking(TestCaseWithTree):
-
-    def test_lock_read(self):
-        work_tree = self.make_branch_and_tree('wt')
-        tree = self.workingtree_to_test_tree(work_tree)
-        self.assertThat(tree.lock_read, ReturnsUnlockable(tree))

=== modified file 'bzrlib/tests/per_workingtree/test_locking.py'
--- bzrlib/tests/per_workingtree/test_locking.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_workingtree/test_locking.py	2009-08-25 23:38:10 +0000
@@ -24,7 +24,6 @@
     lockdir,
     )
 from bzrlib.tests import TestSkipped
-from bzrlib.tests.matchers import *
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 
@@ -45,10 +44,6 @@
         self.assertFalse(wt.is_locked())
         self.assertFalse(wt.branch.is_locked())
 
-    def test_lock_read_returns_unlocker(self):
-        wt = self.make_branch_and_tree('.')
-        self.assertThat(wt.lock_read, ReturnsUnlockable(wt))
-
     def test_trivial_lock_write_unlock(self):
         """Locking for write and unlocking should work trivially."""
         wt = self.make_branch_and_tree('.')
@@ -64,10 +59,6 @@
         self.assertFalse(wt.is_locked())
         self.assertFalse(wt.branch.is_locked())
 
-    def test_lock_write_returns_unlocker(self):
-        wt = self.make_branch_and_tree('.')
-        self.assertThat(wt.lock_write, ReturnsUnlockable(wt))
-
     def test_trivial_lock_tree_write_unlock(self):
         """Locking for tree write is ok when the branch is not locked."""
         wt = self.make_branch_and_tree('.')
@@ -83,10 +74,6 @@
         self.assertFalse(wt.is_locked())
         self.assertFalse(wt.branch.is_locked())
 
-    def test_lock_tree_write_returns_unlocker(self):
-        wt = self.make_branch_and_tree('.')
-        self.assertThat(wt.lock_tree_write, ReturnsUnlockable(wt))
-
     def test_trivial_lock_tree_write_branch_read_locked(self):
         """It is ok to lock_tree_write when the branch is read locked."""
         wt = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/test_remote.py'
--- bzrlib/tests/test_remote.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/test_remote.py	2010-05-03 04:08:50 +0000
@@ -2301,11 +2301,11 @@
         transport_path = 'quack'
         repo, client = self.setup_fake_client_and_repository(transport_path)
         client.add_success_response('ok', 'a token')
-        token = repo.lock_write().repository_token
+        result = repo.lock_write()
         self.assertEqual(
             [('call', 'Repository.lock_write', ('quack/', ''))],
             client._calls)
-        self.assertEqual('a token', token)
+        self.assertEqual('a token', result)
 
     def test_lock_write_already_locked(self):
         transport_path = 'quack'

=== modified file 'bzrlib/tests/test_smart.py'
--- bzrlib/tests/test_smart.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/test_smart.py	2010-03-02 22:25:58 +0000
@@ -767,8 +767,8 @@
 class TestLockedBranch(tests.TestCaseWithMemoryTransport):
 
     def get_lock_tokens(self, branch):
-        branch_token = branch.lock_write().branch_token
-        repo_token = branch.repository.lock_write().repository_token
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
         branch.repository.unlock()
         return branch_token, repo_token
 
@@ -1073,7 +1073,7 @@
             response)
 
 
-class TestSmartServerBranchRequestSetParent(TestLockedBranch):
+class TestSmartServerBranchRequestSetParent(tests.TestCaseWithMemoryTransport):
 
     def test_set_parent_none(self):
         branch = self.make_branch('base', format="1.9")
@@ -1082,10 +1082,12 @@
         branch.unlock()
         request = smart_branch.SmartServerBranchRequestSetParentLocation(
             self.get_transport())
-        branch_token, repo_token = self.get_lock_tokens(branch)
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
         try:
             response = request.execute('base', branch_token, repo_token, '')
         finally:
+            branch.repository.unlock()
             branch.unlock()
         self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), response)
         self.assertEqual(None, branch.get_parent())
@@ -1094,11 +1096,13 @@
         branch = self.make_branch('base', format="1.9")
         request = smart_branch.SmartServerBranchRequestSetParentLocation(
             self.get_transport())
-        branch_token, repo_token = self.get_lock_tokens(branch)
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
         try:
             response = request.execute('base', branch_token, repo_token,
             'http://bar/')
         finally:
+            branch.repository.unlock()
             branch.unlock()
         self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), response)
         self.assertEqual('http://bar/', branch.get_parent())
@@ -1133,7 +1137,7 @@
             response)
 
 
-class TestSmartServerBranchRequestLockWrite(TestLockedBranch):
+class TestSmartServerBranchRequestLockWrite(tests.TestCaseWithMemoryTransport):
 
     def setUp(self):
         tests.TestCaseWithMemoryTransport.setUp(self)
@@ -1161,7 +1165,7 @@
         backing = self.get_transport()
         request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.')
-        branch_token = branch.lock_write().branch_token
+        branch_token = branch.lock_write()
         branch.leave_lock_in_place()
         branch.unlock()
         response = request.execute('')
@@ -1176,7 +1180,9 @@
         backing = self.get_transport()
         request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
-        branch_token, repo_token = self.get_lock_tokens(branch)
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
+        branch.repository.unlock()
         branch.leave_lock_in_place()
         branch.repository.leave_lock_in_place()
         branch.unlock()
@@ -1197,7 +1203,9 @@
         backing = self.get_transport()
         request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
-        branch_token, repo_token = self.get_lock_tokens(branch)
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
+        branch.repository.unlock()
         branch.leave_lock_in_place()
         branch.repository.leave_lock_in_place()
         branch.unlock()
@@ -1218,7 +1226,7 @@
         request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
         repo = branch.repository
-        repo_token = repo.lock_write().repository_token
+        repo_token = repo.lock_write()
         repo.leave_lock_in_place()
         repo.unlock()
         response = request.execute('')
@@ -1241,7 +1249,7 @@
         self.assertEqual('LockFailed', error_name)
 
 
-class TestSmartServerBranchRequestUnlock(TestLockedBranch):
+class TestSmartServerBranchRequestUnlock(tests.TestCaseWithMemoryTransport):
 
     def setUp(self):
         tests.TestCaseWithMemoryTransport.setUp(self)
@@ -1251,7 +1259,9 @@
         request = smart_branch.SmartServerBranchRequestUnlock(backing)
         branch = self.make_branch('.', format='knit')
         # Lock the branch
-        branch_token, repo_token = self.get_lock_tokens(branch)
+        branch_token = branch.lock_write()
+        repo_token = branch.repository.lock_write()
+        branch.repository.unlock()
         # Unlock the branch (and repo) object, leaving the physical locks
         # in place.
         branch.leave_lock_in_place()
@@ -1281,12 +1291,13 @@
         request = smart_branch.SmartServerBranchRequestUnlock(backing)
         branch = self.make_branch('.', format='knit')
         # Lock the repository.
-        repo_token = branch.repository.lock_write().repository_token
+        repo_token = branch.repository.lock_write()
         branch.repository.leave_lock_in_place()
         branch.repository.unlock()
         # Issue branch lock_write request on the unlocked branch (with locked
         # repo).
-        response = request.execute('', 'branch token', repo_token)
+        response = request.execute(
+            '', 'branch token', repo_token)
         self.assertEqual(
             smart_req.SmartServerResponse(('TokenMismatch',)), response)
         # Cleanup
@@ -1599,7 +1610,7 @@
         backing = self.get_transport()
         request = smart_repo.SmartServerRepositoryLockWrite(backing)
         repository = self.make_repository('.', format='knit')
-        repo_token = repository.lock_write().repository_token
+        repo_token = repository.lock_write()
         repository.leave_lock_in_place()
         repository.unlock()
         response = request.execute('')
@@ -1647,7 +1658,7 @@
         request = smart_repo.SmartServerRepositoryInsertStreamLocked(
             backing)
         repository = self.make_repository('.', format='knit')
-        lock_token = repository.lock_write().repository_token
+        lock_token = repository.lock_write()
         response = request.execute('', '', lock_token)
         self.assertEqual(None, response)
         response = request.do_chunk(self.make_empty_byte_stream(repository))
@@ -1661,7 +1672,7 @@
         request = smart_repo.SmartServerRepositoryInsertStreamLocked(
             backing)
         repository = self.make_repository('.', format='knit')
-        lock_token = repository.lock_write().repository_token
+        lock_token = repository.lock_write()
         self.assertRaises(
             errors.TokenMismatch, request.execute, '', '', 'wrong-token')
         repository.unlock()
@@ -1676,7 +1687,7 @@
         backing = self.get_transport()
         request = smart_repo.SmartServerRepositoryUnlock(backing)
         repository = self.make_repository('.', format='knit')
-        token = repository.lock_write().repository_token
+        token = repository.lock_write()
         repository.leave_lock_in_place()
         repository.unlock()
         response = request.execute('', token)

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2010-05-06 23:41:35 +0000
+++ bzrlib/transform.py	2010-04-30 11:35:43 +0000
@@ -1798,12 +1798,9 @@
             executable = self.is_executable(file_id, path)
         return kind, executable, None
 
-    def is_locked(self):
-        return False
-
     def lock_read(self):
         # Perhaps in theory, this should lock the TreeTransform?
-        return self
+        pass
 
     def unlock(self):
         pass

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2010-05-06 23:41:35 +0000
+++ bzrlib/workingtree.py	2010-04-30 11:35:43 +0000
@@ -1798,51 +1798,34 @@
             raise errors.ObjectNotLocked(self)
 
     def lock_read(self):
-        """Lock the tree for reading.
-
-        This also locks the branch, and can be unlocked via self.unlock().
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See Branch.lock_read, and WorkingTree.unlock."""
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_read()
         try:
-            self._control_files.lock_read()
-            return self
+            return self._control_files.lock_read()
         except:
             self.branch.unlock()
             raise
 
     def lock_tree_write(self):
-        """See MutableTree.lock_tree_write, and WorkingTree.unlock.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See MutableTree.lock_tree_write, and WorkingTree.unlock."""
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_read()
         try:
-            self._control_files.lock_write()
-            return self
+            return self._control_files.lock_write()
         except:
             self.branch.unlock()
             raise
 
     def lock_write(self):
-        """See MutableTree.lock_write, and WorkingTree.unlock.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See MutableTree.lock_write, and WorkingTree.unlock."""
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_write()
         try:
-            self._control_files.lock_write()
-            return self
+            return self._control_files.lock_write()
         except:
             self.branch.unlock()
             raise
@@ -2653,14 +2636,10 @@
 
         In Format2 WorkingTrees we have a single lock for the branch and tree
         so lock_tree_write() degrades to lock_write().
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
         """
         self.branch.lock_write()
         try:
-            self._control_files.lock_write()
-            return self
+            return self._control_files.lock_write()
         except:
             self.branch.unlock()
             raise

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2010-05-06 23:41:35 +0000
+++ bzrlib/workingtree_4.py	2010-04-30 11:03:59 +0000
@@ -567,11 +567,7 @@
             return _mod_revision.NULL_REVISION
 
     def lock_read(self):
-        """See Branch.lock_read, and WorkingTree.unlock.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See Branch.lock_read, and WorkingTree.unlock."""
         self.branch.lock_read()
         try:
             self._control_files.lock_read()
@@ -590,7 +586,6 @@
         except:
             self.branch.unlock()
             raise
-        return self
 
     def _lock_self_write(self):
         """This should be called after the branch is locked."""
@@ -611,25 +606,16 @@
         except:
             self.branch.unlock()
             raise
-        return self
 
     def lock_tree_write(self):
-        """See MutableTree.lock_tree_write, and WorkingTree.unlock.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See MutableTree.lock_tree_write, and WorkingTree.unlock."""
         self.branch.lock_read()
-        return self._lock_self_write()
+        self._lock_self_write()
 
     def lock_write(self):
-        """See MutableTree.lock_write, and WorkingTree.unlock.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """See MutableTree.lock_write, and WorkingTree.unlock."""
         self.branch.lock_write()
-        return self._lock_self_write()
+        self._lock_self_write()
 
     @needs_tree_write_lock
     def move(self, from_paths, to_dir, after=False):
@@ -1873,9 +1859,6 @@
             return None
         return ie.executable
 
-    def is_locked(self):
-        return self._locked
-
     def list_files(self, include_root=False, from_dir=None, recursive=True):
         # We use a standard implementation, because DirStateRevisionTree is
         # dealing with one of the parents of the current state
@@ -1894,18 +1877,13 @@
             yield path, 'V', entry.kind, entry.file_id, entry
 
     def lock_read(self):
-        """Lock the tree for a set of operations.
-
-        :return: An object with an unlock method which will release the lock
-            obtained.
-        """
+        """Lock the tree for a set of operations."""
         if not self._locked:
             self._repository.lock_read()
             if self._dirstate._lock_token is None:
                 self._dirstate.lock_read()
                 self._dirstate_locked = True
         self._locked += 1
-        return self
 
     def _must_be_locked(self):
         if not self._locked:

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2010-05-06 23:41:35 +0000
+++ doc/developers/testing.txt	2010-04-16 07:56:51 +0000
@@ -772,15 +772,12 @@
 
 TestCase
     A base TestCase that extends the Python standard library's
-    TestCase in several ways.  TestCase is build on
-    ``testtools.TestCase``, which gives it support for more assertion
-    methods (e.g.  ``assertContainsRe``), ``addCleanup``, and other
-    features (see its API docs for details).  It also has a ``setUp`` that
-    makes sure that global state like registered hooks and loggers won't
-    interfere with your test.  All tests should use this base class
-    (whether directly or via a subclass).  Note that we are trying not to
-    add more assertions at this point, and instead to build up a library
-    of ``bzrlib.tests.matchers``.
+    TestCase in several ways.  It adds more assertion methods (e.g.
+    ``assertContainsRe``), ``addCleanup``, and other features (see its API
+    docs for details).  It also has a ``setUp`` that makes sure that
+    global state like registered hooks and loggers won't interfere with
+    your test.  All tests should use this base class (whether directly or
+    via a subclass).
 
 TestCaseWithMemoryTransport
     Extends TestCase and adds methods like ``get_transport``,

